==> cassandra-all-1.2.10-sources.jar: org/apache/cassandra/io/util/ThrottledReader.java <==
package org.apache.cassandra.io.util;
/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */


import java.io.File;
import java.io.FileNotFoundException;

import com.google.common.util.concurrent.RateLimiter;

public class ThrottledReader extends RandomAccessReader
{
    private final RateLimiter limiter;

    protected ThrottledReader(File file, RateLimiter limiter) throws FileNotFoundException
    {
        super(file, RandomAccessReader.DEFAULT_BUFFER_SIZE, true, null);
        this.limiter = limiter;
    }

    protected void reBuffer()
    {
        limiter.acquire(buffer.length);
        super.reBuffer();
    }

    public static ThrottledReader open(File file, RateLimiter limiter)
    {
        try
        {
            return new ThrottledReader(file, limiter);
        }
        catch (FileNotFoundException e)
        {
            throw new RuntimeException(e);
        }
    }
}

==> cassandra-all-2.1.5-sources.jar: org/apache/cassandra/io/util/ThrottledReader.java <==
package org.apache.cassandra.io.util;
/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */


import java.io.File;
import java.io.FileNotFoundException;

import com.google.common.util.concurrent.RateLimiter;

public class ThrottledReader extends RandomAccessReader
{
    private final RateLimiter limiter;

    protected ThrottledReader(File file, long overrideLength, RateLimiter limiter) throws FileNotFoundException
    {
        super(file, RandomAccessReader.DEFAULT_BUFFER_SIZE, overrideLength, null);
        this.limiter = limiter;
    }

    protected void reBuffer()
    {
        limiter.acquire(buffer.length);
        super.reBuffer();
    }

    public static ThrottledReader open(File file, long overrideLength, RateLimiter limiter)
    {
        try
        {
            return new ThrottledReader(file, overrideLength, limiter);
        }
        catch (FileNotFoundException e)
        {
            throw new RuntimeException(e);
        }
    }
}
